@@ -13,6 +13,7 @@
 #define I _Complex_I
 
 #include <sys/cdefs.h>
+#include <ieeefp.h>
 
 __BEGIN_DECLS
 
@@ -24,12 +25,10 @@ float complex cacosf(float complex);
 /* 7.3.5.2 The casin functions */
 double complex casin(double complex);
 float complex casinf(float complex);
-long double complex casinl(long double complex);
 
 /* 7.3.5.1 The catan functions */
 double complex catan(double complex);
 float complex catanf(float complex);
-long double complex catanl(long double complex);
 
 /* 7.3.5.1 The ccos functions */
 double complex ccos(double complex);
@@ -76,19 +75,11 @@ float complex cexpf(float complex);
 /* 7.3.7.2 The clog functions */
 double complex clog(double complex);
 float complex clogf(float complex);
-long double complex clogl(long double complex);
 
 /* 7.3.8 Power and absolute-value functions */
 /* 7.3.8.1 The cabs functions */
-/*#ifndef __LIBM0_SOURCE__ */
-/* avoid conflict with historical cabs(struct complex) */
-/* double cabs(double complex) __RENAME(__c99_cabs);
-   float cabsf(float complex) __RENAME(__c99_cabsf);
-   #endif
-*/
-long double cabsl(long double complex) ;
-double cabs(double complex) ;
-float cabsf(float complex) ;
+double cabs(double complex);
+float cabsf(float complex);
 
 /* 7.3.8.2 The cpow functions */
 double complex cpow(double complex, double complex);
@@ -97,41 +88,46 @@ float complex cpowf(float complex, float complex);
 /* 7.3.8.3 The csqrt functions */
 double complex csqrt(double complex);
 float complex csqrtf(float complex);
-long double complex csqrtl(long double complex);
 
 /* 7.3.9 Manipulation functions */
-/* 7.3.9.1 The carg functions */ 
+/* 7.3.9.1 The carg functions */
 double carg(double complex);
 float cargf(float complex);
-long double cargl(long double complex);
 
 /* 7.3.9.2 The cimag functions */
 double cimag(double complex);
 float cimagf(float complex);
-long double cimagl(long double complex);
 
 /* 7.3.9.3 The conj functions */
 double complex conj(double complex);
 float complex conjf(float complex);
-long double complex conjl(long double complex);
 
 /* 7.3.9.4 The cproj functions */
 double complex cproj(double complex);
 float complex cprojf(float complex);
-long double complex cprojl(long double complex);
 
 /* 7.3.9.5 The creal functions */
 double creal(double complex);
 float crealf(float complex);
-long double creall(long double complex);
 
 #if __GNU_VISIBLE
 double complex clog10(double complex);
 float complex clog10f(float complex);
 #endif
 
-#if defined(__CYGWIN__) || defined(_LDBL_EQ_DBL)
+#ifdef _HAVE_LONG_DOUBLE
+long double complex csqrtl(long double complex);
+long double cabsl(long double complex) ;
+long double complex cprojl(long double complex);
+long double creall(long double complex);
+long double complex conjl(long double complex);
+long double cimagl(long double complex);
+
+#ifdef _HAVE_LONG_DOUBLE_MATH
+long double cargl(long double complex);
+long double complex casinl(long double complex);
 long double complex cacosl(long double complex);
+long double complex catanl(long double complex);
 long double complex ccosl(long double complex);
 long double complex csinl(long double complex);
 long double complex ctanl(long double complex);
@@ -142,11 +138,14 @@ long double complex ccoshl(long double complex);
 long double complex csinhl(long double complex);
 long double complex ctanhl(long double complex);
 long double complex cexpl(long double complex);
+long double complex clogl(long double complex);
 long double complex cpowl(long double complex, long double complex);
 #if __GNU_VISIBLE
 long double complex clog10l(long double complex);
 #endif
-#endif /* __CYGWIN__ */
+#endif /* _HAVE_LONG_DOUBLE_MATH */
+
+#endif /* _HAVE_LONG_DOUBLE */
 
 __END_DECLS
 
