@@ -49,9 +49,7 @@ int	access (const char *__path, int __amode);
 unsigned  alarm (unsigned __secs);
 int     chdir (const char *__path);
 int     chmod (const char *__path, mode_t __mode);
-#if !defined(__INSIDE_CYGWIN__)
 int     chown (const char *__path, uid_t __owner, gid_t __group);
-#endif
 #if __BSD_VISIBLE || (__XSI_VISIBLE >= 4 && __POSIX_VISIBLE < 200112)
 int     chroot (const char *__path);
 #endif
@@ -78,7 +76,7 @@ int     dup3 (int __fildes, int __fildes2, int flags);
 int	eaccess (const char *__path, int __mode);
 #endif
 #if __XSI_VISIBLE
-void	encrypt (char *__block, int __edflag);
+void	encrypt (char *, int);
 #endif
 #if __BSD_VISIBLE || (__XSI_VISIBLE && __XSI_VISIBLE < 500)
 void	endusershell (void);
@@ -107,11 +105,9 @@ int     fchdir (int __fildes);
 #if __POSIX_VISIBLE >= 199309
 int     fchmod (int __fildes, mode_t __mode);
 #endif
-#if !defined(__INSIDE_CYGWIN__)
 #if __BSD_VISIBLE || __XSI_VISIBLE >= 4 || __POSIX_VISIBLE >= 200809
 int     fchown (int __fildes, uid_t __owner, gid_t __group);
 #endif
-#endif
 #if __ATFILE_VISIBLE
 int	fchownat (int __dirfd, const char *__path, uid_t __owner, gid_t __group, int __flags);
 #endif
@@ -134,11 +130,9 @@ int	getdomainname  (char *__name, size_t __len);
 #if __BSD_VISIBLE
 int     getentropy (void *, size_t);
 #endif
-#if !defined(__INSIDE_CYGWIN__)
 gid_t   getegid (void);
 uid_t   geteuid (void);
 gid_t   getgid (void);
-#endif
 int     getgroups (int __gidsetsize, gid_t __grouplist[]);
 #if __BSD_VISIBLE || __XSI_VISIBLE >= 4
 long    gethostid (void);
@@ -163,9 +157,7 @@ pid_t   getppid (void);
 #if __POSIX_VISIBLE >= 200809 || __XSI_VISIBLE >= 4
 pid_t   getsid (pid_t);
 #endif
-#if !defined(__INSIDE_CYGWIN__)
 uid_t   getuid (void);
-#endif
 #if __BSD_VISIBLE || (__XSI_VISIBLE && __XSI_VISIBLE < 500)
 char *	getusershell (void);
 #endif
@@ -179,11 +171,9 @@ int     isatty (int __fildes);
 #if __BSD_VISIBLE
 int        issetugid (void);
 #endif
-#if !defined(__INSIDE_CYGWIN__)
 #if __BSD_VISIBLE || __XSI_VISIBLE >= 4 || __POSIX_VISIBLE >= 200809
 int     lchown (const char *__path, uid_t __owner, gid_t __group);
 #endif
-#endif
 int     link (const char *__path1, const char *__path2);
 #if __ATFILE_VISIBLE
 int     linkat (int __dirfd1, const char *__path1, int __dirfd2, const char *__path2, int __flags);
@@ -214,7 +204,7 @@ int     pipe2 (int __fildes[2], int flags);
 ssize_t pread (int __fd, void *__buf, size_t __nbytes, off_t __offset);
 ssize_t pwrite (int __fd, const void *__buf, size_t __nbytes, off_t __offset);
 #endif
-_READ_WRITE_RETURN_TYPE read (int __fd, void *__buf, size_t __nbyte);
+ssize_t read (int __fd, void *__buf, size_t __nbyte);
 #if __BSD_VISIBLE
 int	rresvport (int *__alport);
 int	revoke (char *__path);
@@ -226,13 +216,11 @@ int	ruserok (const char *rhost, int superuser, const char *ruser, const char *lu
 #if __BSD_VISIBLE || (__XSI_VISIBLE >= 4 && __POSIX_VISIBLE < 200112)
 void *  sbrk (ptrdiff_t __incr);
 #endif
-#if !defined(__INSIDE_CYGWIN__)
 #if __BSD_VISIBLE || __POSIX_VISIBLE >= 200112
 int     setegid (gid_t __gid);
 int     seteuid (uid_t __uid);
 #endif
 int     setgid (gid_t __gid);
-#endif
 #if __BSD_VISIBLE
 int	setgroups (int ngroups, const gid_t *grouplist);
 #endif
@@ -243,14 +231,12 @@ int     setpgid (pid_t __pid, pid_t __pgid);
 #if __SVID_VISIBLE || __XSI_VISIBLE >= 500
 int     setpgrp (void);
 #endif
-#if (__BSD_VISIBLE || __XSI_VISIBLE >= 4) && !defined(__INSIDE_CYGWIN__)
+#if __BSD_VISIBLE || __XSI_VISIBLE >= 4
 int	setregid (gid_t __rgid, gid_t __egid);
 int	setreuid (uid_t __ruid, uid_t __euid);
 #endif
 pid_t   setsid (void);
-#if !defined(__INSIDE_CYGWIN__)
 int     setuid (uid_t __uid);
-#endif
 #if __BSD_VISIBLE || (__XSI_VISIBLE && __XSI_VISIBLE < 500)
 void	setusershell (void);
 #endif
@@ -270,7 +256,7 @@ int 	usleep (useconds_t __useconds);
 #if __BSD_VISIBLE
 int     vhangup (void);
 #endif
-_READ_WRITE_RETURN_TYPE write (int __fd, const void *__buf, size_t __nbyte);
+ssize_t write (int __fd, const void *__buf, size_t __nbyte);
 
 #ifdef __CYGWIN__
 # define __UNISTD_GETOPT__
@@ -287,7 +273,7 @@ extern int optreset;			/* getopt(3) external variable */
 pid_t   vfork (void);
 #endif
 
-#ifdef _COMPILING_NEWLIB
+#ifdef _LIBC
 /* Provide prototypes for most of the _<systemcall> names that are
    provided in newlib for some compilers.  */
 int     close (int __fildes);
@@ -299,11 +285,8 @@ _off_t  lseek (int __fildes, _off_t __offset, int __whence);
 #ifdef __LARGE64_FILES
 _off64_t lseek64 (int __filedes, _off64_t __offset, int __whence);
 #endif
-_READ_WRITE_RETURN_TYPE _read (int __fd, void *__buf, size_t __nbyte);
 void *  sbrk (ptrdiff_t __incr);
 int     unlink (const char *__path);
-_READ_WRITE_RETURN_TYPE _write (int __fd, const void *__buf, size_t __nbyte);
-int     execve (const char *__path, char * const __argv[], char * const __envp[]);
 #endif
 
 #if !defined(__INSIDE_CYGWIN__)
