@@ -132,9 +132,10 @@ __weak_vector_table(void)
 	 * Exception vector that lives at the
 	 * start of program text (usually 0x0)
 	 */
-#if __ARM_ARCH_ISA_THUMB == 2
+#if __thumb2__
 	/* Thumb 2 processors start in thumb mode */
 	__asm__(".thumb");
+	__asm__(".syntax unified");
 	__asm__("b.w _start");
 	__asm__("b.w arm_undef_vector");
 	__asm__("b.w arm_svc_vector");
