@@ -26,42 +26,27 @@ DESCRIPTION
 	non-reentrant functions, such as strtok.
 */
 
+#define _DEFAULT_SOURCE
+
 #include <stdlib.h>
-#include <reent.h>
-
-#ifdef _REENT_ONLY
-#ifndef REENTRANT_SYSCALLS_PROVIDED
-#define REENTRANT_SYSCALLS_PROVIDED
-#endif
+#ifndef TINY_STDIO
+#include "../stdio/local.h"
 #endif
 
-/* Interim cleanup code */
-
 void
-cleanup_glue (struct _reent *ptr,
-     struct _glue *glue)
-{
-  /* Have to reclaim these in reverse order: */
-  if (glue->_next)
-    cleanup_glue (ptr, glue->_next);
-
-  free (glue);
-}
-
-void
-_reclaim_reent (struct _reent *ptr)
+_reclaim_reent (void *ptr)
 {
+  (void) ptr;
+#ifndef _REENT_THREAD_LOCAL
   if (ptr != _impure_ptr)
+#endif
     {
 #ifndef TINY_STDIO
-      if (ptr->__sdidinit)
+      if (_REENT_CLEANUP(ptr))
 	{
 	  /* cleanup won't reclaim memory 'coz usually it's run
 	     before the program exits, and who wants to wait for that? */
-	  ptr->__cleanup (ptr);
-
-	  if (ptr->__sglue._next)
-	    cleanup_glue (ptr, ptr->__sglue._next);
+	  _REENT_CLEANUP(ptr) ();
 	}
 #endif
       /* Malloc memory not reclaimed; no good way to return memory anyway. */
