@@ -58,7 +58,7 @@ static char sccsid[] = "@(#)hash.c	8.9 (Berkeley) 6/16/94";
 
 static int   alloc_segs(HTAB *, int);
 static int   flush_meta(HTAB *);
-static int   hash_access(HTAB *, ACTION, DBT *, DBT *);
+static int   hash_access(HTAB *, HASH_ACTION, DBT *, DBT *);
 static int   hash_close(DB *);
 static int   hash_delete(const DB *, const DBT *, u_int);
 static int   hash_fd(const DB *);
@@ -70,7 +70,7 @@ static int   hash_sync(const DB *, u_int);
 static int   hdestroy(HTAB *);
 static HTAB *init_hash(HTAB *, const char *, const HASHINFO *);
 static int   init_htab(HTAB *, int);
-#if (BYTE_ORDER == LITTLE_ENDIAN)
+#if (_BYTE_ORDER == _LITTLE_ENDIAN)
 static void  swap_header(HTAB *);
 static void  swap_header_copy(HASHHDR *, HASHHDR *);
 #endif
@@ -160,7 +160,7 @@ __hash_open (const char *file,
 #endif
 			new_table = 1;
 
-#ifdef HAVE_FCNTL
+#ifdef _HAVE_FCNTL
 		(void)fcntl(hashp->fp, F_SETFD, 1);
 #endif
 	}
@@ -175,7 +175,7 @@ __hash_open (const char *file,
 			hashp->hash = __default_hash;
 
 		hdrsize = read(hashp->fp, &hashp->hdr, sizeof(HASHHDR));
-#if (BYTE_ORDER == LITTLE_ENDIAN)
+#if (_BYTE_ORDER == _LITTLE_ENDIAN)
 		swap_header(hashp);
 #endif
 		if (hdrsize == -1)
@@ -516,7 +516,7 @@ static int
 flush_meta(HTAB *hashp)
 {
 	HASHHDR *whdrp;
-#if (BYTE_ORDER == LITTLE_ENDIAN)
+#if (_BYTE_ORDER == _LITTLE_ENDIAN)
 	HASHHDR whdr;
 #endif
 	int fp, i, wsize;
@@ -529,7 +529,7 @@ flush_meta(HTAB *hashp)
 
 	fp = hashp->fp;
 	whdrp = &hashp->hdr;
-#if (BYTE_ORDER == LITTLE_ENDIAN)
+#if (_BYTE_ORDER == _LITTLE_ENDIAN)
 	whdrp = &whdr;
 	swap_header_copy(&hashp->hdr, whdrp);
 #endif
@@ -621,7 +621,7 @@ hash_delete(const DB *dbp,
  */
 static int
 hash_access(HTAB *hashp,
-            ACTION action,
+            HASH_ACTION action,
             DBT *key,
             DBT *val)
 {
@@ -649,7 +649,7 @@ hash_access(HTAB *hashp,
 	for (bp = (__uint16_t *)rbufp->page, n = *bp++, ndx = 1; ndx < n;)
 		if (bp[1] >= REAL_KEY) {
 			/* Real key/data pair */
-			if (size == off - *bp &&
+                        if (size == off - (int) *bp &&
 			    memcmp(kp, rbufp->page + *bp, size) == 0)
 				goto found;
 			off = bp[1];
@@ -953,7 +953,7 @@ alloc_segs(HTAB *hashp, int nsegs)
 	return (0);
 }
 
-#if (BYTE_ORDER == LITTLE_ENDIAN)
+#if (_BYTE_ORDER == _LITTLE_ENDIAN)
 /*
  * Hashp->hdr needs to be byteswapped.
  */
