@@ -21,8 +21,6 @@
 #include <stdarg.h>
 #include "local.h"
 
-#ifndef _REENT_ONLY
-
 int
 fiscanf(FILE *fp, const char *fmt, ...)
 {
@@ -30,22 +28,7 @@ fiscanf(FILE *fp, const char *fmt, ...)
   va_list ap;
 
   va_start (ap, fmt);
-  ret = __svfiscanf_r (_REENT, fp, fmt, ap);
+  ret = _svfiscanf ( fp, fmt, ap);
   va_end (ap);
   return ret;
 }
-
-#endif /* !_REENT_ONLY */
-
-int
-_fiscanf_r(struct _reent *ptr, FILE *fp, const char *fmt, ...)
-{
-  int ret;
-  va_list ap;
-
-  va_start (ap, fmt);
-  ret = __svfiscanf_r (ptr, fp, fmt, ap);
-  va_end (ap);
-  return (ret);
-}
-
