@@ -32,8 +32,8 @@ SYNOPSIS
 	#include <stdio.h>
 	long ftell(FILE *<[fp]>);
 	off_t ftello(FILE *<[fp]>);
-	long _ftell_r(struct _reent *<[ptr]>, FILE *<[fp]>);
-	off_t _ftello_r(struct _reent *<[ptr]>, FILE *<[fp]>);
+	long ftell( FILE *<[fp]>);
+	off_t ftello( FILE *<[fp]>);
 
 DESCRIPTION
 Objects of type <<FILE>> can have a ``position'' that records how much
@@ -83,7 +83,7 @@ static char sccsid[] = "%W% (Berkeley) %G%";
 #include "local.h"
 
 _off_t
-_ftello_r (struct _reent * ptr,
+ftello (
        register FILE * fp)
 {
   _fpos_t pos;
@@ -96,7 +96,7 @@ _ftello_r (struct _reent * ptr,
 
   if (fp->_seek == NULL)
     {
-      __errno_r(ptr) = ESPIPE;
+      _REENT_ERRNO(ptr) = ESPIPE;
       _newlib_flockfile_exit (fp);
       return (_off_t) -1;
     }
@@ -106,7 +106,7 @@ _ftello_r (struct _reent * ptr,
       fp->_p != NULL && fp->_p - fp->_bf._base > 0 &&
       (fp->_flags & __SAPP))
     {
-      pos = fp->_seek (ptr, fp->_cookie, (_fpos_t) 0, SEEK_END);
+      pos = fp->_seek (fp->_cookie, (_fpos_t) 0, SEEK_END);
       if (pos == (_fpos_t) -1)
 	{
           _newlib_flockfile_exit (fp);
@@ -117,7 +117,7 @@ _ftello_r (struct _reent * ptr,
     pos = fp->_offset;
   else
     {
-      pos = fp->_seek (ptr, fp->_cookie, (_fpos_t) 0, SEEK_CUR);
+      pos = fp->_seek (fp->_cookie, (_fpos_t) 0, SEEK_CUR);
       if (pos == (_fpos_t) -1)
         {
           _newlib_flockfile_exit (fp);
@@ -148,13 +148,3 @@ _ftello_r (struct _reent * ptr,
   _newlib_flockfile_end (fp);
   return (_off_t) pos;
 }
-
-#ifndef _REENT_ONLY
-
-_off_t
-ftello (register FILE * fp)
-{
-  return _ftello_r (_REENT, fp);
-}
-
-#endif /* !_REENT_ONLY */
