@@ -23,8 +23,6 @@
 #include <stdarg.h>
 #include "local.h"
 
-#ifndef _REENT_ONLY
-
 int
 fwscanf (FILE *__restrict fp, const wchar_t *__restrict fmt, ...)
 {
@@ -32,22 +30,7 @@ fwscanf (FILE *__restrict fp, const wchar_t *__restrict fmt, ...)
   va_list ap;
 
   va_start (ap, fmt);
-  ret = _vfwscanf_r (_REENT, fp, fmt, ap);
+  ret = vfwscanf ( fp, fmt, ap);
   va_end (ap);
   return ret;
 }
-
-#endif /* !_REENT_ONLY */
-
-int
-_fwscanf_r (struct _reent *ptr, FILE *fp, const wchar_t *fmt, ...)
-{
-  int ret;
-  va_list ap;
-
-  va_start (ap, fmt);
-  ret = _vfwscanf_r (ptr, fp, fmt, ap);
-  va_end (ap);
-  return (ret);
-}
-
