@@ -22,34 +22,15 @@
 #include <stdarg.h>
 #include "local.h"
 
-#ifndef _REENT_ONLY
-
 int
 iprintf (const char *fmt, ...)
 {
   int ret;
   va_list ap;
-  struct _reent *ptr = _REENT;
 
   _REENT_SMALL_CHECK_INIT (ptr);
   va_start (ap, fmt);
-  ret = _vfiprintf_r (ptr, _stdout_r (ptr), fmt, ap);
-  va_end (ap);
-  return ret;
-}
-
-#endif /* ! _REENT_ONLY */
-
-int
-_iprintf_r (struct _reent *ptr,
-       const char *fmt, ...)
-{
-  int ret;
-  va_list ap;
-
-  _REENT_SMALL_CHECK_INIT (ptr);
-  va_start (ap, fmt);
-  ret = _vfiprintf_r (ptr, _stdout_r (ptr), fmt, ap);
+  ret = vfiprintf ( _stdout_r (ptr), fmt, ap);
   va_end (ap);
   return ret;
 }
