@@ -60,13 +60,13 @@ SYNOPSIS
 	int mkostemp(char *<[path]>, int <[flags]>);
 	int mkostemps(char *<[path]>, int <[suffixlen]>, int <[flags]>);
 
-	char *_mktemp_r(struct _reent *<[reent]>, char *<[path]>);
-	char *_mkdtemp_r(struct _reent *<[reent]>, char *<[path]>);
-	int *_mkstemp_r(struct _reent *<[reent]>, char *<[path]>);
-	int *_mkstemps_r(struct _reent *<[reent]>, char *<[path]>, int <[len]>);
-	int *_mkostemp_r(struct _reent *<[reent]>, char *<[path]>,
+	char *mktemp( char *<[path]>);
+	char *mkdtemp( char *<[path]>);
+	int *mkstemp( char *<[path]>);
+	int *mkstemps( char *<[path]>, int <[len]>);
+	int *mkostemp( char *<[path]>,
 			 int <[flags]>);
-	int *_mkostemps_r(struct _reent *<[reent]>, char *<[path]>, int <[len]>,
+	int *mkostemps( char *<[path]>, int <[len]>,
 			  int <[flags]>);
 
 DESCRIPTION
@@ -139,7 +139,7 @@ Supporting OS subroutines required: <<getpid>>, <<mkdir>>, <<open>>, <<stat>>.
 #include <unistd.h>
 
 static int
-_gettemp (struct _reent *ptr,
+_gettemp (
        char *path,
        register int *doopen,
        int domkdir,
@@ -155,13 +155,12 @@ _gettemp (struct _reent *ptr,
 #endif
   unsigned int pid;
 
-  (void) ptr;
   pid = getpid ();
   for (trv = path; *trv; ++trv)		/* extra X's get set to 0's */
     continue;
   if (trv - path < (ptrdiff_t) suffixlen)
     {
-      __errno_r(ptr) = EINVAL;
+      _REENT_ERRNO(ptr) = EINVAL;
       return 0;
     }
   trv -= suffixlen;
@@ -173,7 +172,7 @@ _gettemp (struct _reent *ptr,
     }
   if (end - trv < 6)
     {
-      __errno_r(ptr) = EINVAL;
+      _REENT_ERRNO(ptr) = EINVAL;
       return 0;
     }
 
@@ -197,7 +196,7 @@ _gettemp (struct _reent *ptr,
 	    return (0);
 	  if (!(sbuf.st_mode & S_IFDIR))
 	    {
-	      __errno_r(ptr) = ENOTDIR;
+	      _REENT_ERRNO(ptr) = ENOTDIR;
 	      return (0);
 	    }
 	  *trv = '/';
@@ -211,12 +210,12 @@ _gettemp (struct _reent *ptr,
       if (domkdir)
 	{
 #ifdef HAVE_MKDIR
-	  if (_mkdir_r (ptr, path, 0700) == 0)
+	  if (mkdir ( path, 0700) == 0)
 	    return 1;
-	  if (__errno_r(ptr) != EEXIST)
+	  if (_REENT_ERRNO(ptr) != EEXIST)
 	    return 0;
 #else /* !HAVE_MKDIR */
-	  __errno_r(ptr) = ENOSYS;
+	  _REENT_ERRNO(ptr) = ENOSYS;
 	  return 0;
 #endif /* !HAVE_MKDIR */
 	}
@@ -227,7 +226,7 @@ _gettemp (struct _reent *ptr,
 	  if ((*doopen = open (path, O_CREAT | O_EXCL | O_RDWR | flags,
 				  0600)) >= 0)
 	    return 1;
-	  if (__errno_r(ptr) != EEXIST)
+	  if (_REENT_ERRNO(ptr) != EEXIST)
 	    return 0;
 	}
 #ifdef __USE_INTERNAL_STAT64
@@ -235,7 +234,7 @@ _gettemp (struct _reent *ptr,
 #else
       else if (stat (path, &sbuf))
 #endif
-	return (__errno_r(ptr) == ENOENT ? 1 : 0);
+	return (_REENT_ERRNO(ptr) == ENOENT ? 1 : 0);
 
       /* tricky little algorithm for backward compatibility */
       for (trv = start;;)
@@ -263,111 +262,57 @@ _gettemp (struct _reent *ptr,
 #endif
 
 int
-_mkstemp_r (struct _reent *ptr,
+mkstemp (
        char *path)
 {
   int fd;
 
-  return (_gettemp (ptr, path, &fd, 0, 0, O_BINARY) ? fd : -1);
+  return (_gettemp (path, &fd, 0, 0, O_BINARY) ? fd : -1);
 }
 
 #if !defined _ELIX_LEVEL || _ELIX_LEVEL >= 4
 char *
-_mkdtemp_r (struct _reent *ptr,
+mkdtemp (
        char *path)
 {
-  return (_gettemp (ptr, path, (int *) NULL, 1, 0, 0) ? path : NULL);
+  return (_gettemp (path, (int *) NULL, 1, 0, 0) ? path : NULL);
 }
 
 int
-_mkstemps_r (struct _reent *ptr,
+mkstemps (
        char *path,
        int len)
 {
   int fd;
 
-  return (_gettemp (ptr, path, &fd, 0, len, O_BINARY) ? fd : -1);
+  return (_gettemp (path, &fd, 0, len, O_BINARY) ? fd : -1);
 }
 
 int
-_mkostemp_r (struct _reent *ptr,
+mkostemp (
        char *path,
        int flags)
 {
   int fd;
 
-  return (_gettemp (ptr, path, &fd, 0, 0, flags & ~O_ACCMODE) ? fd : -1);
+  return (_gettemp (path, &fd, 0, 0, flags & ~O_ACCMODE) ? fd : -1);
 }
 
 int
-_mkostemps_r (struct _reent *ptr,
+mkostemps (
        char *path,
        int len,
        int flags)
 {
   int fd;
 
-  return (_gettemp (ptr, path, &fd, 0, len, flags & ~O_ACCMODE) ? fd : -1);
+  return (_gettemp (path, &fd, 0, len, flags & ~O_ACCMODE) ? fd : -1);
 }
 #endif /* _ELIX_LEVEL */
 
 char *
-_mktemp_r (struct _reent *ptr,
+mktemp (
        char *path)
 {
-  return (_gettemp (ptr, path, (int *) NULL, 0, 0, 0) ? path : (char *) NULL);
+  return (_gettemp (path, (int *) NULL, 0, 0, 0) ? path : (char *) NULL);
 }
-
-#ifndef _REENT_ONLY
-
-int
-mkstemp (char *path)
-{
-  int fd;
-
-  return (_gettemp (_REENT, path, &fd, 0, 0, O_BINARY) ? fd : -1);
-}
-
-# if !defined _ELIX_LEVEL || _ELIX_LEVEL >= 4
-char *
-mkdtemp (char *path)
-{
-  return (_gettemp (_REENT, path, (int *) NULL, 1, 0, 0) ? path : NULL);
-}
-
-int
-mkstemps (char *path,
-       int len)
-{
-  int fd;
-
-  return (_gettemp (_REENT, path, &fd, 0, len, O_BINARY) ? fd : -1);
-}
-
-int
-mkostemp (char *path,
-       int flags)
-{
-  int fd;
-
-  return (_gettemp (_REENT, path, &fd, 0, 0, flags & ~O_ACCMODE) ? fd : -1);
-}
-
-int
-mkostemps (char *path,
-       int len,
-       int flags)
-{
-  int fd;
-
-  return (_gettemp (_REENT, path, &fd, 0, len, flags & ~O_ACCMODE) ? fd : -1);
-}
-# endif /* _ELIX_LEVEL */
-
-char *
-mktemp (char *path)
-{
-  return (_gettemp (_REENT, path, (int *) NULL, 0, 0, 0) ? path : (char *) NULL);
-}
-
-#endif /* ! defined (_REENT_ONLY) */
