@@ -99,17 +99,17 @@ SYNOPSIS
 	char *vasnprintf(char *<[str]>, size_t *<[size]>, const char *<[fmt]>,
                          va_list <[list]>);
 
-	int _vprintf_r(struct _reent *<[reent]>, const char *<[fmt]>,
+	int vprintf( const char *<[fmt]>,
                         va_list <[list]>);
-	int _vfprintf_r(struct _reent *<[reent]>, FILE *<[fp]>,
+	int vfprintf( FILE *<[fp]>,
                         const char *<[fmt]>, va_list <[list]>);
-	int _vsprintf_r(struct _reent *<[reent]>, char *<[str]>,
+	int vsprintf( char *<[str]>,
                         const char *<[fmt]>, va_list <[list]>);
-	int _vasprintf_r(struct _reent *<[reent]>, char **<[str]>,
+	int vasprintf( char **<[str]>,
                          const char *<[fmt]>, va_list <[list]>);
-	int _vsnprintf_r(struct _reent *<[reent]>, char *<[str]>,
+	int vsnprintf( char *<[str]>,
                          size_t <[size]>, const char *<[fmt]>, va_list <[list]>);
-	char *_vasnprintf_r(struct _reent *<[reent]>, char *<[str]>,
+	char *vasnprintf( char *<[str]>,
                             size_t *<[size]>, const char *<[fmt]>, va_list <[list]>);
 
 DESCRIPTION
@@ -145,11 +145,10 @@ static char *rcsid = "$Id$";
    This code is large and complicated...  */
 #include <newlib.h>
 
-#define VFPRINTF vfprintf
 #ifdef STRING_ONLY
-# define _VFPRINTF_R _svfprintf_r
+# define VFPRINTF svfprintf
 #else
-# define _VFPRINTF_R _vfprintf_r
+# define VFPRINTF vfprintf
 #endif
 
 #define _DEFAULT_SOURCE
@@ -168,16 +167,16 @@ static char *rcsid = "$Id$";
 #include "vfieeefp.h"
 #include "nano-vfprintf_local.h"
 
-/* The __ssputs_r function is shared between all versions of vfprintf
+/* The _ssputs function is shared between all versions of vfprintf
    and vfwprintf.  */
 #ifdef STRING_ONLY
 int
-__ssputs_r (struct _reent *ptr,
+_ssputs (
        FILE *fp,
        const char *buf,
        size_t len)
 {
-  register int w;
+  register size_t w;
 
   w = fp->_w;
   if (len >= w && fp->_flags & (__SMBF | __SOPT))
@@ -192,7 +191,7 @@ __ssputs_r (struct _reent *ptr,
        * that it can add a trailing \0 without
        * reallocating.  The new allocation should thus be
        * max(prev_size*1.5, curpos+len+1).  */
-      int newsize = fp->_bf._size * 3 / 2;
+      size_t newsize = fp->_bf._size * 3 / 2;
       if (newsize < curpos + len + 1)
 	newsize = curpos + len + 1;
       if (fp->_flags & __SOPT)
@@ -201,7 +200,7 @@ __ssputs_r (struct _reent *ptr,
 	  str = (unsigned char *)malloc (newsize);
 	  if (!str)
 	    {
-	      errno = ENOMEM;
+	      _REENT_ERRNO(ptr) = ENOMEM;
 	      goto err;
 	    }
 	  memcpy (str, fp->_bf._base, curpos);
@@ -215,7 +214,7 @@ __ssputs_r (struct _reent *ptr,
 	      /* Free unneeded buffer.  */
 	      free (fp->_bf._base);
 	      /* Ensure correct errno, even if free changed it.  */
-	      errno = ENOMEM;
+	      _REENT_ERRNO(ptr) = ENOMEM;
 	      goto err;
 	    }
 	}
@@ -237,17 +236,17 @@ err:
   fp->_flags |= __SERR;
   return EOF;
 }
-/* __ssprint_r is the original implementation of __SPRINT.  In nano
-   version formatted IO it is reimplemented as __ssputs_r for non-wide
-   char output, but __ssprint_r cannot be discarded because it is used
+/* _ssprint is the original implementation of _SPRINT.  In nano
+   version formatted IO it is reimplemented as _ssputs for non-wide
+   char output, but _ssprint cannot be discarded because it is used
    by a serial of functions like svfwprintf for wide char output.  */
 int
-__ssprint_r (struct _reent *ptr,
+_ssprint (
        FILE *fp,
        register struct __suio *uio)
 {
   register size_t len;
-  register int w;
+  register size_t w;
   register struct __siov *iov;
   register const char *p = NULL;
 
@@ -281,7 +280,7 @@ __ssprint_r (struct _reent *ptr,
 	   * that it can add a trailing \0 without
 	   * reallocating.  The new allocation should thus be
 	   * max(prev_size*1.5, curpos+len+1).  */
-	  int newsize = fp->_bf._size * 3 / 2;
+	  size_t newsize = fp->_bf._size * 3 / 2;
 	  if (newsize < curpos + len + 1)
 	    newsize = curpos + len + 1;
 
@@ -291,7 +290,7 @@ __ssprint_r (struct _reent *ptr,
 	      str = (unsigned char *)malloc (newsize);
 	      if (!str)
 		{
-		  errno = ENOMEM;
+		  _REENT_ERRNO(ptr) = ENOMEM;
 		  goto err;
 		}
 	      memcpy (str, fp->_bf._base, curpos);
@@ -306,7 +305,7 @@ __ssprint_r (struct _reent *ptr,
 		  /* Free unneeded buffer.  */
 		  free (fp->_bf._base);
 		  /* Ensure correct errno, even if free changed it.  */
-		  errno = ENOMEM;
+		  _REENT_ERRNO(ptr) = ENOMEM;
 		  goto err;
 		}
 	    }
@@ -345,7 +344,7 @@ err:
 /* Flush out all the vectors defined by the given uio,
    then reset it so that it can be reused.  */
 int
-__sprint_r (struct _reent *ptr,
+_sprint (
        FILE *fp,
        register struct __suio *uio)
 {
@@ -371,7 +370,7 @@ __sprint_r (struct _reent *ptr,
 	    len = iov->iov_len / sizeof (wchar_t);
 	    for (i = 0; i < len; i++)
 	      {
-		if (_fputwc_r (ptr, p[i], fp) == WEOF)
+		if (fputwc ( p[i], fp) == WEOF)
 		  {
 		    err = -1;
 		    goto out;
@@ -381,7 +380,8 @@ __sprint_r (struct _reent *ptr,
 	}
       else
 #endif
-	err = __sfvwrite_r(ptr, fp, uio);
+	err = _sfvwrite( fp, uio);
+  goto out;
 out:
   uio->uio_resid = 0;
   uio->uio_iovcnt = 0;
@@ -389,23 +389,23 @@ out:
 }
 
 _NOINLINE_STATIC int
-__sfputc_r (struct _reent *ptr,
+_sfputc (
        int c,
        FILE *fp)
 {
   if (--fp->_w >= 0 || (fp->_w >= fp->_lbfsize && (char)c != '\n'))
     return (*fp->_p++ = c);
   else
-    return (__swbuf_r(ptr, c, fp));
+    return (_swbuf( c, fp));
 }
 
 int
-__sfputs_r (struct _reent *ptr,
+_sfputs (
        FILE *fp,
        const char *buf,
        size_t len)
 {
-  register int i;
+  register size_t i;
 
 #if defined _WIDE_ORIENT && (!defined _ELIX_LEVEL || _ELIX_LEVEL >= 4)
   if (fp->_flags2 & __SWID)
@@ -415,7 +415,7 @@ __sfputs_r (struct _reent *ptr,
       p = (wchar_t *) buf;
       for (i = 0; i < (len / sizeof (wchar_t)); i++)
 	{
-	  if (_fputwc_r (ptr, p[i], fp) == WEOF)
+	  if (fputwc ( p[i], fp) == WEOF)
 	    return -1;
 	}
     }
@@ -425,7 +425,7 @@ __sfputs_r (struct _reent *ptr,
       for (i = 0; i < len; i++)
 	{
 	  /* Call __sfputc_r to skip _fputc_r.  */
-	  if (__sfputc_r (ptr, (int)buf[i], fp) == EOF)
+	  if (_sfputc ( (int)buf[i], fp) == EOF)
 	    return -1;
 	}
     }
@@ -433,28 +433,10 @@ __sfputs_r (struct _reent *ptr,
 }
 #endif /* STRING_ONLY.  */
 
-int _VFPRINTF_R (struct _reent *, FILE *, const char *, va_list);
-
-#ifndef STRING_ONLY
-int
-VFPRINTF (FILE * fp,
-       const char *fmt0,
-       va_list ap)
-{
-  int result;
-  result = _VFPRINTF_R (_REENT, fp, fmt0, ap);
-  return result;
-}
-
-int
-vfiprintf (FILE *, const char *, __VALIST)
-       _ATTRIBUTE ((__alias__("vfprintf")));
-#endif
-
 #ifdef STRING_ONLY
-# define __SPRINT __ssputs_r
+# define __SPRINT _ssputs
 #else
-# define __SPRINT __sfputs_r
+# define __SPRINT _sfputs
 #endif
 
 /* Do not need FLUSH for all sprintf functions.  */
@@ -465,7 +447,7 @@ vfiprintf (FILE *, const char *, __VALIST)
 #endif
 
 int
-_VFPRINTF_R (struct _reent *data,
+VFPRINTF (
        FILE * fp,
        const char *fmt0,
        va_list ap)
@@ -478,7 +460,7 @@ _VFPRINTF_R (struct _reent *data,
   va_list ap_copy;
 
   /* Output function pointer.  */
-  int (*pfunc)(struct _reent *, FILE *, const char *, size_t len);
+  int (*pfunc)(FILE *, const char *, size_t len);
 
   pfunc = __SPRINT;
 
@@ -501,7 +483,7 @@ _VFPRINTF_R (struct _reent *data,
       fp->_bf._base = fp->_p = malloc (64);
       if (!fp->_p)
 	{
-	  errno = ENOMEM;
+	  _REENT_ERRNO(data) = ENOMEM;
 	  return EOF;
 	}
       fp->_bf._size = 64;
@@ -548,7 +530,7 @@ _VFPRINTF_R (struct _reent *data,
        *	-- ANSI X3J11
        */
       flag_chars = "#-0+ ";
-      for (; cp = memchr (flag_chars, *fmt, 5); fmt++)
+      for (; (cp = memchr (flag_chars, *fmt, 5)); fmt++)
 	prt_data.flags |= (1 << (cp - flag_chars));
 
       if (prt_data.flags & SPACESGN)
@@ -633,7 +615,7 @@ _VFPRINTF_R (struct _reent *data,
 	}
       else
 #endif
-	n = _printf_i (data, &prt_data, fp, pfunc, &ap_copy);
+	n = _printf_i (&prt_data, fp, pfunc, &ap_copy);
 
       if (n == -1)
 	goto error;
@@ -651,11 +633,11 @@ error:
 }
 
 #ifdef STRING_ONLY
-int
-_svfiprintf_r (struct _reent *, FILE *, const char *, __VALIST)
-       _ATTRIBUTE ((__alias__("_svfprintf_r")));
+int __nonnull((1))
+svfiprintf ( FILE *, const char *, __VALIST)
+       _ATTRIBUTE ((__alias__("svfprintf")));
 #else
-int
-_vfiprintf_r (struct _reent *, FILE *, const char *, __VALIST)
-       _ATTRIBUTE ((__alias__("_vfprintf_r")));
+int __nonnull((1))
+vfiprintf ( FILE *, const char *, __VALIST)
+       _ATTRIBUTE ((__alias__("vfprintf")));
 #endif
