@@ -93,11 +93,11 @@ typedef struct memstream {
 
 /* Write up to non-zero N bytes of BUF into the stream described by COOKIE,
    returning the number of bytes written or EOF on failure.  */
-static _READ_WRITE_RETURN_TYPE
-memwriter (struct _reent *ptr,
+static ssize_t
+memwriter (
        void *cookie,
        const char *buf,
-       _READ_WRITE_BUFSIZE_TYPE n)
+       size_t n)
 {
   memstream *c = (memstream *) cookie;
   char *cbuf = *c->pbuf;
@@ -106,7 +106,7 @@ memwriter (struct _reent *ptr,
      big that user cannot do ftello.  */
   if (sizeof (OFF_T) == sizeof (size_t) && (ssize_t) (c->pos + n) < 0)
     {
-      __errno_r(ptr) = EFBIG;
+      _REENT_ERRNO(ptr) = EFBIG;
       return EOF;
     }
   /* Grow the buffer, if necessary.  Choose a geometric growth factor
@@ -147,7 +147,7 @@ memwriter (struct _reent *ptr,
 /* Seek to position POS relative to WHENCE within stream described by
    COOKIE; return resulting position or fail with EOF.  */
 static _fpos_t
-memseeker (struct _reent *ptr,
+memseeker (
        void *cookie,
        _fpos_t pos,
        int whence)
@@ -161,18 +161,18 @@ memseeker (struct _reent *ptr,
     offset += c->eof;
   if (offset < 0)
     {
-      __errno_r(ptr) = EINVAL;
+      _REENT_ERRNO(ptr) = EINVAL;
       offset = -1;
     }
-  else if ((size_t) offset != offset)
+  else if ((OFF_T) (size_t) offset != offset)
     {
-      __errno_r(ptr) = ENOSPC;
+      _REENT_ERRNO(ptr) = ENOSPC;
       offset = -1;
     }
 #ifdef __LARGE64_FILES
   else if ((_fpos_t) offset != offset)
     {
-      __errno_r(ptr) = EOVERFLOW;
+      _REENT_ERRNO(ptr) = EOVERFLOW;
       offset = -1;
     }
 #endif /* __LARGE64_FILES */
@@ -214,7 +214,7 @@ memseeker (struct _reent *ptr,
    COOKIE; return resulting position or fail with EOF.  */
 #ifdef __LARGE64_FILES
 static _fpos64_t
-memseeker64 (struct _reent *ptr,
+memseeker64 (
        void *cookie,
        _fpos64_t pos,
        int whence)
@@ -228,12 +228,12 @@ memseeker64 (struct _reent *ptr,
     offset += c->eof;
   if (offset < 0)
     {
-      __errno_r(ptr) = EINVAL;
+      _REENT_ERRNO(ptr) = EINVAL;
       offset = -1;
     }
-  else if ((size_t) offset != offset)
+  else if ((_off64_t) (size_t) offset != offset)
     {
-      __errno_r(ptr) = ENOSPC;
+      _REENT_ERRNO(ptr) = ENOSPC;
       offset = -1;
     }
   else
@@ -273,7 +273,7 @@ memseeker64 (struct _reent *ptr,
 
 /* Reclaim resources used by stream described by COOKIE.  */
 static int
-memcloser (struct _reent *ptr,
+memcloser (
        void *cookie)
 {
   memstream *c = (memstream *) cookie;
@@ -292,7 +292,7 @@ memcloser (struct _reent *ptr,
 /* Open a memstream that tracks a dynamic buffer in BUF and SIZE.
    Return the new stream, or fail with NULL.  */
 static FILE *
-internal_open_memstream_r (struct _reent *ptr,
+internalopen_memstream (
        char **buf,
        size_t *size,
        int wide)
@@ -302,10 +302,10 @@ internal_open_memstream_r (struct _reent *ptr,
 
   if (!buf || !size)
     {
-      __errno_r(ptr) = EINVAL;
+      _REENT_ERRNO(ptr) = EINVAL;
       return NULL;
     }
-  if ((fp = __sfp (ptr)) == NULL)
+  if ((fp = __sfp ()) == NULL)
     return NULL;
   if ((c = (memstream *) malloc (sizeof *c)) == NULL)
     {
@@ -374,33 +374,17 @@ internal_open_memstream_r (struct _reent *ptr,
 }
 
 FILE *
-_open_memstream_r (struct _reent *ptr,
+open_memstream (
        char **buf,
        size_t *size)
 {
-  return internal_open_memstream_r (ptr, buf, size, -1);
+  return internalopen_memstream ( buf, size, -1);
 }
 
 FILE *
-_open_wmemstream_r (struct _reent *ptr,
+open_wmemstream (
        wchar_t **buf,
        size_t *size)
 {
-  return internal_open_memstream_r (ptr, (char **)buf, size, 1);
+  return internalopen_memstream ( (char **)buf, size, 1);
 }
-
-#ifndef _REENT_ONLY
-FILE *
-open_memstream (char **buf,
-       size_t *size)
-{
-  return _open_memstream_r (_REENT, buf, size);
-}
-
-FILE *
-open_wmemstream (wchar_t **buf,
-       size_t *size)
-{
-  return _open_wmemstream_r (_REENT, buf, size);
-}
-#endif /* !_REENT_ONLY */
