@@ -62,20 +62,8 @@ static char sccsid[] = "%W% (Berkeley) %G%";
 #undef putchar_unlocked
 
 int
-_putchar_unlocked_r (struct _reent *ptr,
+putchar_unlocked (
        int c)
 {
-  return putc_unlocked (c, _stdout_r (ptr));
+  return putc_unlocked (c, stdout);
 }
-
-#ifndef _REENT_ONLY
-
-int
-putchar_unlocked (int c)
-{
-  /* CHECK_INIT is (eventually) called by __swbuf.  */
-
-  return _putchar_unlocked_r (_REENT, c);
-}
-
-#endif
