@@ -45,10 +45,10 @@ SYNOPSIS
 	wint_t putwchar_unlocked(wchar_t <[wc]>);
 
 	#include <wchar.h>
-	wint_t _putwchar_r(struct _reent *<[reent]>, wchar_t <[wc]>);
+	wint_t putwchar( wchar_t <[wc]>);
 
 	#include <wchar.h>
-	wint_t _putwchar_unlocked_r(struct _reent *<[reent]>, wchar_t <[wc]>);
+	wint_t putwchar_unlocked( wchar_t <[wc]>);
 
 DESCRIPTION
 The <<putwchar>> function or macro is the wide-character equivalent of
@@ -86,13 +86,6 @@ PORTABILITY
 
 #undef putwchar
 
-wint_t
-_putwchar_r (struct _reent *ptr,
-	wchar_t wc)
-{
-  return _fputwc_r (ptr, wc, stdout);
-}
-
 /*
  * Synonym for fputwc(wc, stdout).
  */
