@@ -15,50 +15,27 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
+#define _DEFAULT_SOURCE
 #include <_ansi.h>
 #include <stdio.h>
 #include <stdarg.h>
 #include "local.h"
 
-#ifndef _REENT_ONLY
-
 int
 scanf(const char *__restrict fmt, ...)
 {
   int ret;
   va_list ap;
-  struct _reent *reent = _REENT;
 
   _REENT_SMALL_CHECK_INIT (reent);
   va_start (ap, fmt);
-  ret = _vfscanf_r (reent, _stdin_r (reent), fmt, ap);
+  ret = vfscanf (stdin, fmt, ap);
   va_end (ap);
   return ret;
 }
 
 #ifdef _NANO_FORMATTED_IO
-int
+int __nonnull((1))
 iscanf (const char *, ...)
        _ATTRIBUTE ((__alias__("scanf")));
 #endif
-
-#endif /* !_REENT_ONLY */
-
-int
-_scanf_r(struct _reent *ptr, const char *__restrict fmt, ...)
-{
-  int ret;
-  va_list ap;
-
-  _REENT_SMALL_CHECK_INIT (ptr);
-  va_start (ap, fmt);
-  ret = _vfscanf_r (ptr, _stdin_r (ptr), fmt, ap);
-  va_end (ap);
-  return (ret);
-}
-
-#ifdef _NANO_FORMATTED_IO
-int
-_iscanf_r (struct _reent *, const char *, ...)
-       _ATTRIBUTE ((__alias__("_scanf_r")));
-#endif
