@@ -29,20 +29,8 @@ static char sccsid[] = "%W% (Berkeley) %G%";
 
 #include "local.h"
 
-#ifndef _REENT_ONLY
-
 int
-vasiprintf (char **strp,
-       const char *fmt,
-       va_list ap)
-{
-  return _vasiprintf_r (_REENT, strp, fmt, ap);
-}
-
-#endif /* !_REENT_ONLY */
-
-int
-_vasiprintf_r (struct _reent *ptr,
+vasiprintf (
        char **strp,
        const char *fmt,
        va_list ap)
@@ -54,7 +42,7 @@ _vasiprintf_r (struct _reent *ptr,
   f._bf._base = f._p = NULL;
   f._bf._size = f._w = 0;
   f._file = -1;  /* No file. */
-  ret = _svfiprintf_r (ptr, &f, fmt, ap);
+  ret = svfiprintf ( &f, fmt, ap);
   if (ret >= 0)
     {
       *f._p = 0;
