@@ -22,36 +22,15 @@
 #include <stdarg.h>
 #include "local.h"
 
-#ifndef _REENT_ONLY
-
 int
 vprintf (const char *fmt,
        va_list ap)
 {
-  struct _reent *reent = _REENT;
-
   _REENT_SMALL_CHECK_INIT (reent);
-  return _vfprintf_r (reent, _stdout_r (reent), fmt, ap);
+  return vfprintf ( _stdout_r (reent), fmt, ap);
 }
 
 #ifdef _NANO_FORMATTED_IO
-int
+int __nonnull((1))
 viprintf (const char *, __VALIST) _ATTRIBUTE ((__alias__("vprintf")));
 #endif
-
-#endif /* !_REENT_ONLY */
-
-int
-_vprintf_r (struct _reent *ptr,
-       const char *__restrict fmt,
-       va_list ap)
-{
-  _REENT_SMALL_CHECK_INIT (ptr);
-  return _vfprintf_r (ptr, _stdout_r (ptr), fmt, ap);
-}
-
-#ifdef _NANO_FORMATTED_IO
-int
-_viprintf_r (struct _reent *, const char *, __VALIST)
-       _ATTRIBUTE ((__alias__("_vprintf_r")));
-#endif
