@@ -29,27 +29,8 @@ static char sccsid[] = "%W% (Berkeley) %G%";
 
 #include "local.h"
 
-#ifndef _REENT_ONLY
-
 int
-vsnprintf (char *__restrict str,
-       size_t size,
-       const char *__restrict fmt,
-       va_list ap)
-{
-  return _vsnprintf_r (_REENT, str, size, fmt, ap);
-}
-
-#ifdef _NANO_FORMATTED_IO
-int
-vsniprintf (char *, size_t, const char *, __VALIST)
-       _ATTRIBUTE ((__alias__("vsnprintf")));
-#endif
-
-#endif /* !_REENT_ONLY */
-
-int
-_vsnprintf_r (struct _reent *ptr,
+vsnprintf (
        char *__restrict str,
        size_t size,
        const char *__restrict fmt,
@@ -60,23 +41,23 @@ _vsnprintf_r (struct _reent *ptr,
 
   if (size > INT_MAX)
     {
-      __errno_r(ptr) = EOVERFLOW;
+      _REENT_ERRNO(ptr) = EOVERFLOW;
       return EOF;
     }
   f._flags = __SWR | __SSTR;
   f._bf._base = f._p = (unsigned char *) str;
   f._bf._size = f._w = (size > 0 ? size - 1 : 0);
   f._file = -1;  /* No file. */
-  ret = _svfprintf_r (ptr, &f, fmt, ap);
+  ret = svfprintf ( &f, fmt, ap);
   if (ret < EOF)
-    __errno_r(ptr) = EOVERFLOW;
+    _REENT_ERRNO(ptr) = EOVERFLOW;
   if (size > 0)
     *f._p = 0;
   return ret;
 }
 
 #ifdef _NANO_FORMATTED_IO
-int
-_vsniprintf_r (struct _reent *, char *, size_t, const char *, __VALIST)
-       _ATTRIBUTE ((__alias__("_vsnprintf_r")));
+int __nonnull((1)) _NOTHROW
+vsniprintf (char *, size_t, const char *, __VALIST)
+       _ATTRIBUTE ((__alias__("vsnprintf")));
 #endif
