@@ -86,12 +86,12 @@ Supporting OS subroutines required: <<close>>, <<fstat64>>, <<isatty>>,
  */
 
 _off64_t
-_fseeko64_r (struct _reent *ptr,
+fseeko64 (
      register FILE *fp,
      _off64_t offset,
      int whence)
 {
-  _fpos64_t (*seekfn) (struct _reent *, void *, _fpos64_t, int);
+  _fpos64_t (*seekfn) (void *, _fpos64_t, int);
   _fpos64_t curoff;
 #if _FSEEK_OPTIMIZATION
   _fpos64_t target;
@@ -105,10 +105,10 @@ _fseeko64_r (struct _reent *ptr,
     {
       if ((_off_t) offset != offset)
 	{
-	  __errno_r(ptr) = EOVERFLOW;
+	  _REENT_ERRNO(ptr) = EOVERFLOW;
 	  return EOF;
 	}
-      return (_off64_t) _fseeko_r (ptr, fp, offset, whence);
+      return (_off64_t) fseeko (fp, offset, whence);
     }
 
   /* Make sure stdio is set up.  */
@@ -125,14 +125,14 @@ _fseeko64_r (struct _reent *ptr,
   if (fp->_flags & __SAPP && fp->_flags & __SWR)
     {
       /* So flush the buffer and seek to the end.  */
-      _fflush_r (ptr, fp);
+      fflush (fp);
     }
 
   /* Have to be able to seek.  */
 
   if ((seekfn = fp->_seek64) == NULL)
     {
-      __errno_r(ptr) = ESPIPE;	/* ??? */
+      _REENT_ERRNO(ptr) = ESPIPE;	/* ??? */
       _newlib_flockfile_exit(fp);
       return EOF;
     }
@@ -150,12 +150,12 @@ _fseeko64_r (struct _reent *ptr,
        * we have to first find the current stream offset a la
        * ftell (see ftell for details).
        */
-      _fflush_r (ptr, fp);   /* may adjust seek offset on append stream */
+      fflush (fp);   /* may adjust seek offset on append stream */
       if (fp->_flags & __SOFF)
 	curoff = fp->_offset;
       else
 	{
-	  curoff = seekfn (ptr, fp->_cookie, (_fpos64_t) 0, SEEK_CUR);
+	  curoff = seekfn (fp->_cookie, (_fpos64_t) 0, SEEK_CUR);
 	  if (curoff == -1L)
 	    {
 	      _newlib_flockfile_exit(fp);
@@ -182,7 +182,7 @@ _fseeko64_r (struct _reent *ptr,
       break;
 
     default:
-      __errno_r(ptr) = EINVAL;
+      _REENT_ERRNO(ptr) = EINVAL;
       _newlib_flockfile_exit(fp);
       return (EOF);
     }
@@ -198,7 +198,7 @@ _fseeko64_r (struct _reent *ptr,
    */
 
   if (fp->_bf._base == NULL)
-    __smakebuf_r (ptr, fp);
+    _smakebuf (fp);
 
 #if _FSEEK_OPTIMIZATION
   if (fp->_flags & (__SWR | __SRW | __SNBF | __SNPT))
@@ -326,8 +326,8 @@ _fseeko64_r (struct _reent *ptr,
 dumb:
 #endif
 
-  if (_fflush_r (ptr, fp)
-      || seekfn (ptr, fp->_cookie, offset, whence) == POS_ERR)
+  if (fflush (fp)
+      || seekfn (fp->_cookie, offset, whence) == POS_ERR)
     {
       _newlib_flockfile_exit(fp);
       return EOF;
@@ -343,16 +343,4 @@ dumb:
   return 0;
 }
 
-#ifndef _REENT_ONLY
-
-_off64_t
-fseeko64 (register FILE *fp,
-     _off64_t offset,
-     int whence)
-{
-  return _fseeko64_r (_REENT, fp, offset, whence);
-}
-
-#endif /* !_REENT_ONLY */
-
 #endif /* __LARGE64_FILES */
