@@ -18,11 +18,7 @@ All rights reserved.
 #include <stdio.h>
 
 void
-__eprintf (format, file, line, expression)
-     const char *format;
-     const char *file;
-     unsigned int line;
-     const char *expression;
+__eprintf (const char *format, const char *file, unsigned int line, const char *expression)
 {
   (void) fprintf (stderr, format, file, line, expression);
   abort ();
