@@ -40,10 +40,12 @@ QUICKREF
 	strcoll_l ansi pure
 */
 
+#define _DEFAULT_SOURCE
 #include <string.h>
 
 int
 strcoll_l (const char *a, const char *b, struct __locale_t *locale)
 {
+  (void) locale;
   return strcmp (a, b);
 }
