@@ -114,12 +114,12 @@
     conversion should be performed, but instead any string that aims
     to issue a CR-LF sequence must use <tt>"\r\n"</tt> explicitly.
 
-    stdin, stdout and stderr are macros which refer to an undefined
-    array of FILE pointers, __iob. If you want to use this, your
-    application must define this array and initialize it. It is
-    declared 'const' so that you can place it in ROM if you don't need
-    to modify it after startup. FILEs cannot be placed in ROM as they
-    have values which are modified during runtime.
+    stdin, stdout and stderr are undefined global FILE pointers. If
+    you want to use this, your application must define these variables
+    and initialize them. They are declared 'const' so that you can place
+    them in ROM if you don't need to modify it after startup. FILEs
+    cannot be placed in ROM as they have values which are modified
+    during runtime.
 
     \anchor stdio_without_malloc
     <h3>Running stdio without malloc()</h3>
@@ -254,7 +254,9 @@ struct __file {
 #define __SWR	0x0002		/* OK to write */
 #define __SERR	0x0004		/* found error */
 #define __SEOF	0x0008		/* found EOF */
-#define __SCLOSE 0x0010		/* struct is __file_close with close function */
+#define __SCLOSE 0x0010		/* struct is __file_close */
+#define __SEXT  0x0020          /* struct is __file_ext */
+#define __SBUF  0x0040          /* struct is __file_bufio */
 	int	(*put)(char, struct __file *);	/* function to write one char to device */
 	int	(*get)(struct __file *);	/* function to read one char from device */
 	int	(*flush)(struct __file *);	/* function to flush output to device */
@@ -269,6 +271,25 @@ struct __file_close {
 	int	(*close)(struct __file *);	/* function to close file */
 };
 
+#define FDEV_SETUP_CLOSE(put, get, flush, _close, rwflag) \
+        {                                                               \
+                .file = FDEV_SETUP_STREAM(put, get, flush, (rwflag) | __SCLOSE),   \
+                .close = (_close),                                      \
+        }
+
+struct __file_ext {
+        struct __file_close cfile;              /* close file struct */
+        __off_t (*seek)(struct __file *, __off_t offset, int whence);
+        int     (*setvbuf)(struct __file *, char *buf, int mode, size_t size);
+};
+
+#define FDEV_SETUP_EXT(put, get, flush, close, _seek, _setvbuf, rwflag) \
+        {                                                               \
+                .cfile = FDEV_SETUP_CLOSE(put, get, flush, close, (rwflag) | __SEXT), \
+                .seek = (_seek),                                        \
+                .setvbuf = (_setvbuf),                                  \
+        }
+
 #endif /* not __DOXYGEN__ */
 
 /*@{*/
@@ -282,23 +303,30 @@ typedef __FILE FILE;
 # define __FILE_defined
 #endif
 
+/**
+   This symbol is defined when stdin/stdout/stderr are global
+   variables. When undefined, the old __iob array is used which
+   contains the pointers instead
+*/
+#define PICOLIBC_STDIO_GLOBALS
+
 /**
    Stream that will be used as an input stream by the simplified
    functions that don't take a \c stream argument.
 */
-#define stdin (__iob[0])
+extern FILE *const stdin;
 
 /**
    Stream that will be used as an output stream by the simplified
    functions that don't take a \c stream argument.
 */
-#define stdout (__iob[1])
+extern FILE *const stdout;
 
 /**
    Stream destined for error output.  Unless specifically assigned,
    identical to \c stdout.
 */
-#define stderr (__iob[2])
+extern FILE *const stderr;
 
 /**
    \c EOF declares the value that is returned by various standard IO
@@ -308,6 +336,10 @@ typedef __FILE FILE;
 */
 #define EOF	(-1)
 
+#define	_IOFBF	0		/* setvbuf should set fully buffered */
+#define	_IOLBF	1		/* setvbuf should set line buffered */
+#define	_IONBF	2		/* setvbuf should set unbuffered */
+
 #if defined(__DOXYGEN__)
 /**
    \brief Setup a user-supplied buffer as an stdio stream
@@ -333,10 +365,10 @@ typedef __FILE FILE;
 #else  /* !DOXYGEN */
 #define fdev_setup_stream(stream, p, g, fl, f)	\
 	do { \
+		(stream)->flags = f; \
 		(stream)->put = p; \
 		(stream)->get = g; \
 		(stream)->flush = fl; \
-		(stream)->flags = f; \
 	} while(0)
 #endif /* DOXYGEN */
 
@@ -372,10 +404,10 @@ typedef __FILE FILE;
 #else  /* !DOXYGEN */
 #define FDEV_SETUP_STREAM(p, g, fl, f)		\
 	{ \
-		.put = p, \
-		.get = g, \
-		.flush = fl, \
-		.flags = f, \
+                .flags = (f),                   \
+                .put = (p),                     \
+                .get = (g),                     \
+                .flush = (fl),                  \
 	}
 #endif /* DOXYGEN */
 
@@ -388,8 +420,6 @@ extern "C" {
  * Doxygen documentation can be found in fdevopen.c.
  */
 
-extern struct __file *const __iob[];
-
 extern FILE *fdevopen(int (*__put)(char, FILE*), int (*__get)(FILE*), int(*__flush)(FILE *));
 
 #endif /* not __DOXYGEN__ */
@@ -465,7 +495,7 @@ extern int	fclose(FILE *__stream);
             signed conversion.  A + overrides a space if both are
             used.</li>
       </ul>
-      
+
    -   An optional decimal digit string specifying a minimum field width.
        If the converted value has fewer characters than the field width, it
        will be padded with spaces on the left (or right, if the left-adjustment
@@ -579,7 +609,7 @@ extern int	fclose(FILE *__stream);
 
  */
 
-#ifdef HAVE_FORMAT_ATTRIBUTE
+#ifdef _HAVE_FORMAT_ATTRIBUTE
 #ifdef PICOLIBC_FLOAT_PRINTF_SCANF
 #pragma GCC diagnostic ignored "-Wformat"
 #define __FORMAT_ATTRIBUTE__(__a, __s, __f) __attribute__((__format__ (__a, __s, 0)))
@@ -753,7 +783,7 @@ extern int	getchar(void);
 
    Currently, only a single character can be pushed back onto the
    stream.
-   
+
    The ungetc() function returns the character pushed back after the
    conversion, or \c EOF if the operation fails.  If the value of the
    argument \c c character equals \c EOF, the operation will fail and
@@ -857,6 +887,14 @@ extern int	vscanf(const char *__fmt, va_list __ap) __FORMAT_ATTRIBUTE__(scanf, 1
  */
 extern int	sscanf(const char *__buf, const char *__fmt, ...) __FORMAT_ATTRIBUTE__(scanf, 2, 3);
 
+/**
+   The function \c vscanf performs formatted input, reading the
+   input data from the buffer pointed to by \c buf.
+
+   See vfscanf() for details.
+ */
+extern int	vsscanf(const char *__buf, const char *__fmt, va_list ap) __FORMAT_ATTRIBUTE__(scanf, 2, 0);
+
 /**
    Flush \c stream.
 
@@ -864,29 +902,60 @@ extern int	sscanf(const char *__buf, const char *__fmt, ...) __FORMAT_ATTRIBUTE_
  */
 extern int	fflush(FILE *stream);
 
+#ifndef SEEK_SET
+#define	SEEK_SET	0	/* set file offset to offset */
+#endif
+#ifndef SEEK_CUR
+#define	SEEK_CUR	1	/* set file offset to current plus offset */
+#endif
+#ifndef SEEK_END
+#define	SEEK_END	2	/* set file offset to EOF plus offset */
+#endif
+
 #ifndef __DOXYGEN__
 /* only mentioned for libstdc++ support, not implemented in library */
 #ifndef BUFSIZ
 #define BUFSIZ 512
 #endif
-#define _IONBF 0
 __extension__ typedef long long fpos_t;
 extern int fgetpos(FILE *stream, fpos_t *pos);
 extern FILE *fopen(const char *path, const char *mode);
 extern FILE *freopen(const char *path, const char *mode, FILE *stream);
 extern FILE *fdopen(int, const char *);
+extern FILE *fmemopen(void *buf, size_t size, const char *mode);
 extern int fseek(FILE *stream, long offset, int whence);
+extern int fseeko(FILE *stream, __off_t offset, int whence);
 extern int fsetpos(FILE *stream, fpos_t *pos);
 extern long ftell(FILE *stream);
+extern __off_t ftello(FILE *stream);
 extern int fileno(FILE *);
 extern void perror(const char *s);
 extern int remove(const char *pathname);
 extern int rename(const char *oldpath, const char *newpath);
 extern void rewind(FILE *stream);
 extern void setbuf(FILE *stream, char *buf);
+extern void setbuffer(FILE *stream, char *buf, size_t size);
+extern void setlinebuf(FILE *stream);
 extern int setvbuf(FILE *stream, char *buf, int mode, size_t size);
 extern FILE *tmpfile(void);
 extern char *tmpnam (char *s);
+
+/*
+ * The format of tmpnam names is TXXXXXX, which works with mktemp
+ */
+#define L_tmpnam        8
+
+/*
+ * tmpnam files are created in the current directory
+ */
+#define P_tmpdir        ""
+
+/*
+ * We don't have any way of knowing any underlying POSIX limits,
+ * so just use a reasonably small value here
+ */
+#define TMP_MAX         32
+
 #endif	/* !__DOXYGEN__ */
 
 #ifdef __cplusplus
@@ -925,4 +994,4 @@ __printf_float(float f)
 #define printf_float(x) ((double) (x))
 #endif
 
-#endif /* _STDLIB_H_ */
+#endif /* _STDIO_H_ */
