@@ -47,6 +47,10 @@
 # define SCANF_LONGLONG	(SCANF_FLOAT || defined(_WANT_IO_LONG_LONG))
 #endif
 
+#if defined(SCANF_FLOAT) || defined(_WANT_IO_POS_ARGS)
+#define SCANF_POSITIONAL
+#endif
+
 #ifdef SCANF_LONGLONG
 typedef unsigned long long uint_scanf_t;
 typedef long long int_scanf_t;
@@ -92,33 +96,18 @@ putval (void *addr, int_scanf_t val, uint16_t flags)
     }
 }
 
-static uint_scanf_t
-mulacc (uint_scanf_t val, uint16_t flags, unsigned char c)
-{
-    unsigned char cnt;
-
-    if (flags & FL_OCT) {
-	cnt = 3;
-    } else if (flags & FL_HEX) {
-	cnt = 4;
-    } else {
-	val += (val << 2);
-	cnt = 1;
-    }
-
-    do { val <<= 1; } while (--cnt);
-    return val + c;
-}
+#define CASE_CONVERT    ('a' - 'A')
+#define TOLOW(c)        ((c) | CASE_CONVERT)
 
 static unsigned char
-conv_int (FILE *stream, int *lenp, width_t width, void *addr, uint16_t flags)
+conv_int (FILE *stream, int *lenp, width_t width, void *addr, uint16_t flags, unsigned int base)
 {
     uint_scanf_t val;
     int i;
 
     i = scanf_getc (stream, lenp);			/* after scanf_ungetc()	*/
 
-    switch ((unsigned char)i) {
+    switch (i) {
       case '-':
         flags |= FL_MINUS;
 	FALLTHROUGH;
@@ -128,49 +117,48 @@ conv_int (FILE *stream, int *lenp, width_t width, void *addr, uint16_t flags)
     }
 
     val = 0;
-    flags &= ~FL_WIDTH;
 
-    if (!(flags & (FL_DEC | FL_OCT)) && (unsigned char)i == '0') {
+    /* Leading '0' digit -- check for base indication */
+    if ((unsigned char)i == '0') {
 	if (!--width || (i = scanf_getc (stream, lenp)) < 0)
 	    goto putval;
-	flags |= FL_WIDTH;
-	if ((unsigned char)(i) == 'x' || (unsigned char)(i) == 'X') {
-	    flags |= FL_HEX;
+
+        flags |= FL_ANY;
+
+        if (TOLOW(i) == 'x' && (base == 0 || base == 16)) {
+            base = 16;
+	    if (!--width || (i = scanf_getc(stream, lenp)) < 0)
+		goto putval;
+#ifdef _WANT_IO_PERCENT_B
+        } else if (i == 'b' && base <= 2) {
+            base = 2;
 	    if (!--width || (i = scanf_getc(stream, lenp)) < 0)
 		goto putval;
-	} else {
-	    if (!(flags & FL_HEX))
-		flags |= FL_OCT;
-	}
-    }
-
-/* This fact is used below to parse hexidecimal digit.	*/
-#if	('A' - '0') != (('a' - '0') & ~('A' ^ 'a'))
-# error
 #endif
+	} else if (base == 0 || base == 8) {
+            base = 8;
+        }
+    } else if (base == 0)
+        base = 10;
+
     do {
 	unsigned char c = i;
+
+        /* Map digits to 0..35, non-digits above 35. */
+        if (c > '9')
+            c = TOLOW(c-1) + ('0' - 'a' + 11);
 	c -= '0';
-	if (c > 7) {
-	    if (flags & FL_OCT) goto unget;
-	    if (c > 9) {
-		if (!(flags & FL_HEX)) goto unget;
-		c &= ~('A' ^ 'a');
-		c += '0' - 'A';
-		if (c > 5) {
-		  unget:
-		    scanf_ungetc (i, stream, lenp);
-		    break;
-		}
-		c += 10;
-	    }
+
+        if (c >= base) {
+            scanf_ungetc (i, stream, lenp);
+            break;
 	}
-	val = mulacc (val, flags, c);
-	flags |= FL_WIDTH;
+        flags |= FL_ANY;
+        val = val * base + c;
 	if (!--width) goto putval;
     } while ((i = scanf_getc(stream, lenp)) >= 0);
-    if (!(flags & FL_WIDTH))
-	goto err;
+    if (!(flags & FL_ANY))
+        goto err;
 
   putval:
     if (flags & FL_MINUS) val = -val;
@@ -277,6 +265,29 @@ static int skip_spaces (FILE *stream, int *lenp)
     return i;
 }
 
+#ifdef SCANF_POSITIONAL
+
+typedef struct {
+    va_list     ap;
+} my_va_list;
+
+static void
+skip_to_arg(my_va_list *ap, int target_argno)
+{
+    int current_argno = 1;
+
+    /*
+     * Fortunately, all scanf args are pointers,
+     * and so are the same size as void *
+     */
+    while (current_argno < target_argno) {
+        (void) va_arg(ap->ap, void *);
+        current_argno++;
+    }
+}
+
+#endif
+
 /**
    Formatted input.  This function is the heart of the \b scanf family of
    functions.
@@ -410,12 +421,19 @@ static int skip_spaces (FILE *stream, int *lenp)
      -Wl,-u,vfscanf -lscanf_min -lm
      \endcode
 */
-int vfscanf (FILE * stream, const char *fmt, va_list ap)
+int vfscanf (FILE * stream, const char *fmt, va_list ap_orig)
 {
     unsigned char nconvs;
     unsigned char c;
     width_t width;
     void *addr;
+#ifdef SCANF_POSITIONAL
+    my_va_list my_ap;
+#define ap my_ap.ap
+    va_copy(ap, ap_orig);
+#else
+#define ap ap_orig
+#endif
     uint16_t flags;
     int i;
     int scanf_len = 0;
@@ -450,20 +468,33 @@ int vfscanf (FILE * stream, const char *fmt, va_list ap)
 		c = *fmt++;
 	    }
 
-	    width = 0;
-	    while ((c -= '0') < 10) {
-		flags |= FL_WIDTH;
-		width = width * 10 + c;
-		c = *fmt++;
-	    }
-	    c += '0';
-	    if (flags & FL_WIDTH) {
-		/* C99 says that width must be greater than zero.
-		   To simplify program do treat 0 as error in format.	*/
-		if (!width) break;
-	    } else {
-		width = ~0;
-	    }
+            for (;;) {
+                width = 0;
+                while ((c -= '0') < 10) {
+                    flags |= FL_WIDTH;
+                    width = width * 10 + c;
+                    c = *fmt++;
+                }
+                c += '0';
+                if (flags & FL_WIDTH) {
+#ifdef SCANF_POSITIONAL
+                    if (c == '$') {
+                        flags &= ~FL_WIDTH;
+                        va_end(ap);
+                        va_copy(ap, ap_orig);
+                        skip_to_arg(&my_ap, width);
+                        c = *fmt++;
+                        continue;
+                    }
+#endif
+                    /* C99 says that width must be greater than zero.
+                       To simplify program do treat 0 as error in format.	*/
+                    if (!width) break;
+                } else {
+                    width = ~0;
+                }
+                break;
+            }
 
 	    switch (c) {
 	      case 'h':
@@ -484,6 +515,12 @@ int vfscanf (FILE * stream, const char *fmt, va_list ap)
                 }
 #endif
 		break;
+#ifdef SCANF_LONGLONG
+              case 'L':
+                flags |= FL_LONGLONG;
+                c = *fmt++;
+                break;
+#endif
 #ifdef _WANT_IO_C99_FORMATS
 #ifdef SCANF_LONGLONG
 #define CHECK_LONGLONG(type)                                    \
@@ -511,7 +548,12 @@ int vfscanf (FILE * stream, const char *fmt, va_list ap)
 #endif
 	    }
 
+#ifdef _WANT_IO_PERCENT_B
+#define CNV_BASE	"cdinopsuxXb"
+#else
 #define CNV_BASE	"cdinopsuxX"
+#endif
+
 #if	SCANF_BRACKET
 # define CNV_BRACKET	"["
 #else
@@ -553,6 +595,8 @@ int vfscanf (FILE * stream, const char *fmt, va_list ap)
 
 	    } else {
 
+                unsigned int base = 0;
+
 		if (skip_spaces (stream, lenp) < 0)
 		    goto eof;
 
@@ -578,22 +622,31 @@ int vfscanf (FILE * stream, const char *fmt, va_list ap)
 
 #if  SCANF_FLOAT
 	          case 'p':
+                      if (sizeof(void *) > sizeof(int))
+                          flags |= FL_LONG;
+                      FALLTHROUGH;
 		  case 'x':
 	          case 'X':
-		    flags |= FL_HEX;
+                    base = 16;
 		    goto conv_int;
 
+#ifdef _WANT_IO_PERCENT_B
+                  case 'b':
+                    base = 2;
+                    goto conv_int;
+#endif
+
 	          case 'd':
 		  case 'u':
-		    flags |= FL_DEC;
+                    base = 10;
 		    goto conv_int;
 
 	          case 'o':
-		    flags |= FL_OCT;
+                    base = 8;
 		    FALLTHROUGH;
 		  case 'i':
 		  conv_int:
-		    c = conv_int (stream, lenp, width, addr, flags);
+                    c = conv_int (stream, lenp, width, addr, flags, base);
 		    break;
 
 	          default:		/* e,E,f,F,g,G	*/
@@ -601,19 +654,29 @@ int vfscanf (FILE * stream, const char *fmt, va_list ap)
 #else
 	          case 'd':
 		  case 'u':
-		    flags |= FL_DEC;
+                    base = 10;
 		    goto conv_int;
 
+#ifdef _WANT_IO_PERCENT_B
+                  case 'b':
+                    base = 2;
+                    goto conv_int;
+#endif
+
 	          case 'o':
-		    flags |= FL_OCT;
+                    base = 8;
 		    FALLTHROUGH;
 		  case 'i':
 		    goto conv_int;
 
+                  case 'p':
+                      if (sizeof(void *) > sizeof(int))
+                          flags |= FL_LONG;
+                      FALLTHROUGH;
 		  default:			/* p,x,X	*/
-		    flags |= FL_HEX;
+                    base = 16;
 		  conv_int:
-		    c = conv_int (stream, lenp, width, addr, flags);
+		    c = conv_int (stream, lenp, width, addr, flags, base);
 #endif
 		}
 	    } /* else */
@@ -626,14 +689,21 @@ int vfscanf (FILE * stream, const char *fmt, va_list ap)
 	    if (!(flags & FL_STAR)) nconvs += 1;
 	} /* else */
     } /* while */
+#ifdef PRINTF_POSITIONAL
+    va_end(ap);
+#endif
     return nconvs;
 
   eof:
+#ifdef PRINTF_POSITIONAL
+    va_end(ap);
+#endif
+#undef ap
     return nconvs ? nconvs : EOF;
 }
 
 #if defined(FORMAT_DEFAULT_DOUBLE) && !defined(vfscanf)
-#ifdef HAVE_ALIAS_ATTRIBUTE
+#ifdef _HAVE_ALIAS_ATTRIBUTE
 __strong_reference(vfscanf, __d_vfscanf);
 #else
 int __d_vfscanf (FILE * stream, const char *fmt, va_list ap) { return vfscanf(stream, fmt, ap); }
