@@ -21,15 +21,13 @@
  * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-#include <math.h>
-#include <inttypes.h>
-#include "local.h"
 #include "math_config.h"
 
 // This is only necessary because the implementation of isnan only works
 // properly when long double == double.
 // See: https://sourceware.org/ml/newlib/2014/msg00684.html
-#ifdef _LDBL_EQ_DBL
+
+#if !defined(_NEED_FLOAT_HUGE)
 
 float
 nexttowardf (float x, long double y)
@@ -37,15 +35,27 @@ nexttowardf (float x, long double y)
   uint32_t ux;
   uint32_t e;
 
-  if (isnan(x) || isnan(y))
-    return (long double) x + y;
+  /*
+   * We can't do this if y isn't nan as that might raise INEXACT doing
+   * long double -> float conversion, and we don't want to do this
+   * in long double for machines without long double HW as we won't
+   * get any exceptions in that case.
+   */
+  if (isnan(y))
+      return x + (issignaling(y) ? __builtin_nansf("") : (float) y);
+  if (isnan(x))
+      return x + x;
+
   if ((long double) x == y)
-    return y;
+      return (float) y;
   ux = asuint(x);
   if (x == 0) {
     ux = 1;
     if (signbit(y))
       ux |= 0x80000000;
+    x = asfloat(ux);
+    force_eval_float(x*x);
+    return x;
   } else if ((long double) x < y) {
     if (signbit(x))
       ux--;
@@ -59,18 +69,15 @@ nexttowardf (float x, long double y)
   }
   e = ux & 0x7f800000;
   /* raise overflow if ux.value is infinite and x is finite */
-  if (e == 0x7f800000) {
-    volatile float force_eval;
-    force_eval = x + x;
-    (void) force_eval;
-  }
+  if (e == 0x7f800000)
+    return check_oflowf(opt_barrier_float(x+x));
   /* raise underflow if ux.value is subnormal or zero */
-  if (e == 0) {
-    volatile float force_eval;
-    force_eval = x*x + asfloat(ux)*asfloat(ux);
-    (void) force_eval;
-  }
-  return asfloat(ux);
+  x = asfloat(ux);
+  if (e == 0)
+      return __math_denormf(x);
+  return x;
 }
 
-#endif // _LDBL_EQ_DBL
+_MATH_ALIAS_f_fl(nexttoward)
+
+#endif /* _NEED_FLOAT_HUGE */
