@@ -19,20 +19,24 @@
 
 #include "fdlibm.h"
 
-#ifndef _DOUBLE_IS_32BITS
+#ifdef _NEED_FLOAT64
 
-double
-scalb(double x, double fn)
+__float64
+scalb64(__float64 x, __float64 fn)
 {
-    if (isnan(fn))
-        return fn;
+    if (isnan(fn) || isnan(x))
+        return x + fn;
 
     if (isinf(fn)) {
         if ((x == 0.0 && fn > 0.0) || (isinf(x) && fn < 0.0))
             return __math_invalid(fn);
+        if (fn > 0.0)
+            return fn*x;
+        else
+            return x/(-fn);
     }
 
-    if (rint(fn) != fn)
+    if (rint64(fn) != fn)
         return __math_invalid(fn);
 
     if (fn > 4 * __DBL_MAX_EXP__)
@@ -41,7 +45,9 @@ scalb(double x, double fn)
     if (fn < -4 * __DBL_MAX_EXP__)
         fn = -4 * __DBL_MAX_EXP__;
 
-    return scalbn(x, (int)fn);
+    return scalbn64(x, (int)fn);
 }
 
-#endif /* defined(_DOUBLE_IS_32BITS) */
+_MATH_ALIAS_d_dd(scalb)
+
+#endif /* _NEED_FLOAT64 */
