@@ -25,7 +25,7 @@ frexpf(float x, int *eptr)
     ix = 0x7fffffff & hx;
     *eptr = 0;
     if (!FLT_UWORD_IS_FINITE(ix) || FLT_UWORD_IS_ZERO(ix))
-        return x; /* 0,inf,nan */
+        return x + x; /* 0,inf,nan */
     if (FLT_UWORD_IS_SUBNORMAL(ix)) { /* subnormal */
         x *= two25;
         GET_FLOAT_WORD(hx, x);
@@ -38,12 +38,4 @@ frexpf(float x, int *eptr)
     return x;
 }
 
-#ifdef _DOUBLE_IS_32BITS
-
-double
-frexp(double x, int *eptr)
-{
-    return (double)frexpf((float)x, eptr);
-}
-
-#endif /* defined(_DOUBLE_IS_32BITS) */
+_MATH_ALIAS_f_fI(frexp)
