@@ -6,14 +6,15 @@
 
 #include "fdlibm.h"
 
-#if !defined(_LDBL_EQ_DBL) || !defined(HAVE_ALIAS_ATTRIBUTE)
+#if defined(_NEED_FLOAT_HUGE) && !defined(_HAVE_LONG_DOUBLE_MATH)
 
 long double
 hypotl(long double x, long double y)
 {
-#ifdef _LDBL_EQ_DBL
-    return hypot(x, y);
-#else
+    if ((isinf(x) && isnanl(y) && !__issignalingl(y)) ||
+        (isinf(y) && isnanl(x) && !__issignaling(x)))
+        return (long double)INFINITY;
+
     /* Keep it simple for now...  */
     long double z = sqrtl((x * x) + (y * y));
 #ifdef _WANT_MATH_ERRNO
@@ -21,6 +22,6 @@ hypotl(long double x, long double y)
         errno = ERANGE;
 #endif
     return z;
-#endif
 }
+
 #endif
