@@ -302,4 +302,4 @@
 {37, 0,123,__LINE__, 0x40465197, 0x40000000, 0x403d7fff, 0xfffffffc, 0x4040bfff, 0xfffffffe},	/* 44.6374=f(29.5, 33.5)*/
 {0}
 };
-void test_hypotf(m)   {run_vector_1(m,hypotf_vec,(char *)(hypotf),"hypotf","fff");   }	
+void test_hypotf(int m)   {run_vector_1(m,hypotf_vec,(char *)(hypotf),"hypotf","fff");   }	
