@@ -432,6 +432,7 @@ run_vector_1 (int vector,
   double result;
   float fresult;
 
+#if 0
   if (vector)
   {
 
@@ -483,6 +484,7 @@ run_vector_1 (int vector,
       return;
     }
   }
+#endif
 
   newfunc(name);
   while (p->line)
@@ -677,6 +679,8 @@ test_math (int vector)
   test_modff(vector);
   test_pow_vec(vector);
   test_powf_vec(vector);
+  test_scalb(vector);
+  test_scalbf(vector);
   test_scalbn(vector);
   test_scalbnf(vector);
   test_sin(vector);
