@@ -73,11 +73,11 @@ funcqual (char *a,
 
 
 
-static char one[50];
+static char one[100];
 static char two[50];
 
 
-void test_string()
+void test_string(void)
 {
   /* Test strcmp first because we use it to test other things.  */
   it = "strcmp";
