@@ -12,6 +12,6 @@ is freely granted, provided that this notice is preserved.
     { \
       printf ("Failed " #a " in <%s> at line %d\n", __FILE__, __LINE__); \
       fflush(stdout); \
-      abort(); \
+      exit(1); \
     } \
 }
