@@ -40,6 +40,7 @@
 #include <string.h>
 #include <malloc.h>
 #include <stdlib.h>
+#include <stdint.h>
 
 #ifndef __clang__
 #pragma GCC diagnostic ignored "-Walloc-size-larger-than="
@@ -67,6 +68,13 @@ main(void)
 	}
 	free(r);
 
+	errno = 0;
+	r = malloc(PTRDIFF_MAX);
+	if (r || errno != ENOMEM) {
+                printf("malloc(%ld) should have failed. got %p error %s\n", (long) PTRDIFF_MAX, r, strerror(errno));
+		result++;
+	}
+
 	errno = 0;
 	r = malloc(SIZE_MAX);
 	if (r || errno != ENOMEM) {
