@@ -42,11 +42,32 @@
 #include <sys/stat.h>
 #include <string.h>
 #include <stdlib.h>
+#include <stdarg.h>
+#include <stddef.h>
 
-#ifndef TINY_STDIO
+#ifndef __PICOLIBC__
+# define _WANT_IO_C99_FORMATS
+# define _WANT_IO_LONG_LONG
+# define _WANT_IO_POS_ARGS
+# define printf_float(x) ((double) (x))
+#elif defined(TINY_STDIO)
+# ifdef PICOLIBC_INTEGER_PRINTF_SCANF
+#  ifndef _WANT_IO_POS_ARGS
+#   define NO_POS_ARGS
+#  endif
+# endif
+# ifdef _WANT_IO_PERCENT_B
+#  define BINARY_FORMAT
+# endif
+#else
 #define printf_float(x) ((double) (x))
 
+#ifndef _WANT_IO_POS_ARGS
+#define NO_POS_ARGS
+#endif
+
 #ifdef _NANO_FORMATTED_IO
+
 #ifndef NO_FLOATING_POINT
 extern int _printf_float();
 extern int _scanf_float();
@@ -112,6 +133,16 @@ main(void)
 	}
 #endif
 
+#ifndef NO_POS_ARGS
+        x = y = 0;
+        int r = sscanf("3 4", "%2$d %1$d", &x, &y);
+        if (x != 4 || y != 3 || r != 2) {
+            printf("pos: wanted %d %d (ret %d) got %d %d (ret %d)", 4, 3, 2, x, y, r);
+            errors++;
+            fflush(stdout);
+        }
+#endif
+
 	/*
 	 * test snprintf and vsnprintf to make sure they don't
 	 * overwrite the specified buffer length (even if that is
@@ -135,6 +166,9 @@ main(void)
 				errors++;
 			}
 			if (y > 0 && strncmp(tbuf, "123", y - 1) != 0) {
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wunknown-warning-option"
+#pragma GCC diagnostic ignored "-Wstringop-truncation"
 				strncpy(buf, "123", y - 1);
 				buf[y-1] = '\0';
 				printf("%s: returned buffer want %s got %s\n", name, buf, tbuf);
@@ -149,34 +183,53 @@ main(void)
 
 #define FMT(prefix,conv) "%" prefix conv
 
-#define VERIFY(prefix, conv) do {                                       \
-        sprintf(buf, FMT(prefix, conv), v);                             \
-        sscanf(buf, FMT(prefix, conv), &r);                             \
-        if (v != r) {                                                   \
-                printf("\t%3d: " prefix " " conv " wanted " FMT(prefix, conv) " got " FMT(prefix, conv) "\n", x, v, r); \
+#define VERIFY_BOTH(prefix, oconv, iconv) do {                          \
+            int __n;                                                    \
+            sprintf(buf, FMT(prefix, oconv), v);                        \
+            __n = sscanf(buf, FMT(prefix, iconv), &r);                  \
+            if (v != r || __n != 1) {                                   \
+                printf("\t%3d: " prefix " " oconv " wanted " FMT(prefix, oconv) " got " FMT(prefix, oconv) "\n", x, v, r); \
                 errors++;                                               \
                 fflush(stdout);                                         \
-        }                                                               \
-} while(0)
+            }                                                           \
+        } while(0)
+
+#define VERIFY(prefix, conv) VERIFY_BOTH(prefix, conv, conv)
+
+#ifdef BINARY_FORMAT
+#define VERIFY_BINARY(prefix) VERIFY(prefix, "b")
+#pragma GCC diagnostic ignored "-Wformat"
+#pragma GCC diagnostic ignored "-Wformat-extra-args"
+#else
+#define VERIFY_BINARY(prefix)
+#endif
 
 #define CHECK_RT(type, prefix) do {                                     \
-        for (x = 0; x < (int) (sizeof(type) * 8); x++) {            \
+        for (x = 0; x < (int) (sizeof(type) * 8); x++) {                \
                 type v = (type) (0x123456789abcdef0LL >> (64 - sizeof(type) * 8)) >> x; \
-                type r;                                                 \
+                type r = ~v;                                            \
                 VERIFY(prefix, "d");                                    \
+                r = ~v;                                                 \
                 VERIFY(prefix, "u");                                    \
+                r = ~v;                                                 \
                 VERIFY(prefix, "x");                                    \
+                r = ~v;                                                 \
                 VERIFY(prefix, "o");                                    \
+                r = ~v;                                                 \
+                VERIFY_BINARY(prefix);                                  \
         }                                                               \
         } while(0)
 
+#ifndef _NANO_FORMATTED_IO
 	CHECK_RT(unsigned char, "hh");
+#endif
 	CHECK_RT(unsigned short, "h");
         CHECK_RT(unsigned int, "");
         CHECK_RT(unsigned long, "l");
 #if defined(_WANT_IO_LONG_LONG) || defined(TINY_STDIO)
         CHECK_RT(unsigned long long, "ll");
 #endif
+#ifndef _NANO_FORMATTED_IO
 #if !defined(_WANT_IO_LONG_LONG) && !defined(TINY_STDIO)
 	if (sizeof(intmax_t) <= sizeof(long))
 #endif
@@ -185,7 +238,14 @@ main(void)
 	}
         CHECK_RT(size_t, "z");
         CHECK_RT(ptrdiff_t, "t");
+#endif
 
+        {
+            static int i_addr = 12;
+            void *v = &i_addr;
+            void *r = (void *) -1;
+            VERIFY("", "p");
+        }
 #if defined(TINY_STDIO) || !defined(NO_FLOATING_POINT)
 #ifdef PICOLIBC_FLOAT_PRINTF_SCANF
 #define float_type float
@@ -195,13 +255,8 @@ main(void)
 #if (defined(TINY_STDIO) && !defined(_IO_FLOAT_EXACT))
 #define ERROR_MAX 1e-6
 #else
-#if (!defined(TINY_STDIO) && defined(_WANT_IO_LONG_DOUBLE))
-/* __ldtoa is really broken */
-#define ERROR_MAX 1e-5
-#else
 #define ERROR_MAX 0
 #endif
-#endif
 #else
 #define float_type double
 #define scanf_format "%lf"
